@@ -458,8 +458,7 @@ void LDAPProtocol::get(const QUrl &_url)
                 }
                 qCDebug(KLDAP_LOG) << " estimated size: " << estsize;
                 if (estsize != -1 && !cookie.isEmpty()) {
-                    LdapControls ctrls;
-                    ctrls = serverctrls;
+                    LdapControls ctrls{serverctrls}; // clazy:exclude=container-inside-loop
                     qCDebug(KLDAP_LOG) << "page size: " << mServer.pageSize() << " estimated size: " << estsize;
                     ctrls.append(LdapControl::createPageControl(mServer.pageSize(), cookie));
                     mOp.setServerControls(ctrls);
@@ -736,8 +735,7 @@ void LDAPProtocol::listDir(const QUrl &_url)
     bool critical = true;
     bool isSub = (usrc.extension(QStringLiteral("x-dir"), critical) == QLatin1String("sub"));
 
-//Reactivate it
-    //qCDebug(KLDAP_LOG) << "listDir(" << _url << ")";
+    qCDebug(KLDAP_LOG) << "listDir(" << _url << ")";
 
     changeCheck(usrc);
     if (!mConnected) {
