@@ -21,7 +21,6 @@
 #ifndef KLDAP_LDAPURL_H
 #define KLDAP_LDAPURL_H
 
-#include <QMap>
 #include <QStringList>
 
 #include <QUrl>
@@ -29,6 +28,8 @@
 #include "ldapdn.h"
 #include "kldap_export.h"
 
+// clazy:excludeall=copyable-polymorphic
+
 namespace KLDAP
 {
 
